# petpet

**Create Petpet GIFs!**

## Usage

To create a Petpet GIF, use the following Python code:

```python
import petpet

petpet.make(
    source="[Path to your image file (.png/.jpg/.jpeg)]",
    dest="[Path where the GIF will be saved]"
)
```